@@ -1,20 +1,15 @@
 /*
-** Zabbix
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 package ember
@@ -343,13 +338,13 @@ func TestElement_handleApplication(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
 			el := &Element{
 				ElementType: tt.fields.ElementType,
 			}
-
 			got, err := el.handleApplication(tt.args.decoder)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Element.handleApplication() error = %v, wantErr %v", err, tt.wantErr)
@@ -692,11 +687,12 @@ func TestElement_handleChildren(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
+		tt := tt
+
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
 			el := &Element{}
-
 			got, err := el.handleChildren(tt.args.decoder)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Element.handleChildren() error = %v, wantErr %v", err, tt.wantErr)
@@ -968,14 +964,15 @@ func TestElement_setChild(t *testing.T) {
 			true,
 		},
 	}
+	//nolint:dupl
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
 			el := &Element{
 				Children: tt.fields.Children,
 			}
-
 			got, err := el.setChild(tt.args.childrenDecoder)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Element.setChild() error = %v, wantErr %v", err, tt.wantErr)
@@ -1186,14 +1183,15 @@ func TestElement_handleContent(t *testing.T) {
 			true,
 		},
 	}
+	//nolint:dupl
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
 			el := &Element{
 				ElementType: tt.fields.ElementType,
 			}
-
 			got, err := el.handleContent(tt.args.c)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Element.handleContent() error = %v, wantErr %v", err, tt.wantErr)
@@ -1647,14 +1645,15 @@ func TestElement_handleContentContext(t *testing.T) {
 			true,
 		},
 	}
+	//nolint:dupl
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
 			el := &Element{
 				ElementType: tt.fields.ElementType,
 			}
-
 			got, err := el.handleContentContext(tt.args.decoder)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Element.handleContentContext() error = %v, wantErr %v", err, tt.wantErr)
@@ -1867,11 +1866,11 @@ func TestElement_handlePath(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
 			el := &Element{}
-
 			got, err := el.handlePath(tt.args.decoder)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Element.handlePath() error = %v, wantErr %v", err, tt.wantErr)
@@ -1967,6 +1966,7 @@ func Test_getPath(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -2213,6 +2213,7 @@ func TestGetElement(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -2325,11 +2326,11 @@ func TestElement_handleFunctionContext(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
 			el := &Element{}
-
 			got, err := el.handleFunctionContext(tt.args.context, tt.args.tag)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Element.handleFunctionContext() error = %v, wantErr %v", err, tt.wantErr)
@@ -2466,11 +2467,11 @@ func TestElement_handleNodeContext(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
 			el := &Element{}
-
 			got, err := el.handleNodeContext(tt.args.context, tt.args.tag)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Element.handleNodeContext() error = %v, wantErr %v", err, tt.wantErr)
@@ -2815,6 +2816,7 @@ func TestElement_handleParameterContext(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -2931,13 +2933,13 @@ func TestElement_setValue(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
 			el := &Element{
 				ValueType: tt.fields.ValueType,
 			}
-
 			got, got1, err := el.setValue(tt.args.context)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Element.setValue() error = %v, wantErr %v", err, tt.wantErr)
@@ -3004,6 +3006,7 @@ func TestElement_setDefaultElementValue(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -3069,6 +3072,7 @@ func Test_findWithData(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -3112,6 +3116,7 @@ func Test_handlePathFromUniversal(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -3205,6 +3210,7 @@ func Test_readOverElement(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
@@ -3260,6 +3266,7 @@ func Test_parsePath(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
